"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const path = require("path");
const vscode = require("vscode");
// Import the language client, language client options and server options from VSCode language client.
const node_1 = require("vscode-languageclient/node");
let client;
// Name of the launcher class which contains the main.
const main = 'StdioLauncher';
function activate(context) {
    console.log('Congratulations, your extension "silverlsp" is now active!');
    // Get the java home from the process environment.
    const { JAVA_HOME } = process.env;
    // Get the config settings
    const config = vscode.workspace.getConfiguration("silver");
    console.log(`Using java from JAVA_HOME: ${JAVA_HOME}`);
    // If java home is available continue.
    if (JAVA_HOME) {
        // Java execution path.
        let excecutable = path.join(JAVA_HOME, 'bin', 'java');
        // path to the launcher.jar
        let launcherJar = path.join(__dirname, '..', 'launcher', 'launcher.jar');
        let compilerJar = config.get('compilerJar') || "";
        if (compilerJar && !compilerJar.startsWith("/") && vscode.workspace.workspaceFolders !== undefined) {
            compilerJar = path.join(vscode.workspace.workspaceFolders[0].uri.path, "/", compilerJar);
        }
        let classPath = [launcherJar];
        if (compilerJar) {
            classPath.unshift(compilerJar);
        }
        console.log(classPath);
        let jvmArgs = config.get('jvmArgs') || "";
        const args = [
            // JVM args
            '-cp', classPath.join(":"),
            ...jvmArgs.split(' '),
            // The main class
            main
        ];
        // Set the server options 
        // -- java execution path
        // -- argument to be pass when executing the java command
        let serverOptions = {
            command: excecutable,
            args: args,
            options: {}
        };
        // Options to control the language client
        let clientOptions = {
            documentSelector: [{ scheme: 'file', language: 'silver' }],
            synchronize: {
                configurationSection: 'Silver'
            },
            initializationOptions: {
                'parserName': config.get('parserName')
            }
        };
        // Create the language client and start the client.
        console.log("Launching language server");
        client = new node_1.LanguageClient('silver-langserver', 'Language Support for Silver', serverOptions, clientOptions);
        client.start();
    }
}
exports.activate = activate;
// this method is called when your extension is deactivated
function deactivate() {
    console.log('Your extension "silver" is now deactivated!');
    if (!client) {
        return undefined;
    }
    return client.stop();
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map